pub struct StatueBonusGradeWeight {
pub grade_id: StatueBonusGradeId,
pub weight: PositiveF64,
}Expand description
Вес грейда при ролле бонуса
Fields
grade_id: StatueBonusGradeIdweight: PositiveF64Trait Implementations
Sourceimpl Clone for StatueBonusGradeWeight
impl Clone for StatueBonusGradeWeight
Sourcefn clone(&self) -> StatueBonusGradeWeight
fn clone(&self) -> StatueBonusGradeWeight
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StatueBonusGradeWeight
impl Debug for StatueBonusGradeWeight
Sourceimpl<'de> Deserialize<'de> for StatueBonusGradeWeight
impl<'de> Deserialize<'de> for StatueBonusGradeWeight
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for StatueBonusGradeWeight
impl JsonSchema for StatueBonusGradeWeight
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for StatueBonusGradeWeight
impl Serialize for StatueBonusGradeWeight
Sourceimpl Tsify for StatueBonusGradeWeight
impl Tsify for StatueBonusGradeWeight
const DECL: &'static str = "/**\n * \u{412}\u{435}\u{441} \u{433}\u{440}\u{435}\u{439}\u{434}\u{430} \u{43f}\u{440}\u{438} \u{440}\u{43e}\u{43b}\u{43b}\u{435} \u{431}\u{43e}\u{43d}\u{443}\u{441}\u{430}\n */\nexport interface StatueBonusGradeWeight {\n grade_id: StatueBonusGradeId;\n weight: PositiveF64;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>