pub struct StatueBonusTypeConfig {
pub attribute_id: AttributeId,
pub grade_values: NonEmptyVec<StatueBonusGradeValue>,
}Expand description
Настройки одного типа бонуса — значения для каждого грейда
Fields
attribute_id: AttributeIdgrade_values: NonEmptyVec<StatueBonusGradeValue>Trait Implementations
Sourceimpl Clone for StatueBonusTypeConfig
impl Clone for StatueBonusTypeConfig
Sourcefn clone(&self) -> StatueBonusTypeConfig
fn clone(&self) -> StatueBonusTypeConfig
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StatueBonusTypeConfig
impl Debug for StatueBonusTypeConfig
Sourceimpl<'de> Deserialize<'de> for StatueBonusTypeConfig
impl<'de> Deserialize<'de> for StatueBonusTypeConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for StatueBonusTypeConfig
impl JsonSchema for StatueBonusTypeConfig
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for StatueBonusTypeConfig
impl Serialize for StatueBonusTypeConfig
Sourceimpl Tsify for StatueBonusTypeConfig
impl Tsify for StatueBonusTypeConfig
const DECL: &'static str = "/**\n * \u{41d}\u{430}\u{441}\u{442}\u{440}\u{43e}\u{439}\u{43a}\u{438} \u{43e}\u{434}\u{43d}\u{43e}\u{433}\u{43e} \u{442}\u{438}\u{43f}\u{430} \u{431}\u{43e}\u{43d}\u{443}\u{441}\u{430} \u{2014} \u{437}\u{43d}\u{430}\u{447}\u{435}\u{43d}\u{438}\u{44f} \u{434}\u{43b}\u{44f} \u{43a}\u{430}\u{436}\u{434}\u{43e}\u{433}\u{43e} \u{433}\u{440}\u{435}\u{439}\u{434}\u{430}\n */\nexport interface StatueBonusTypeConfig {\n attribute_id: AttributeId;\n grade_values: NonEmptyVec<StatueBonusGradeValue>;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>