pub struct StatueLevelConfig {
pub level: i64,
pub required_experience: i64,
pub slot_count: NonZeroU64,
pub sets_count: NonZeroU64,
pub grade_weights: NonEmptyVec<StatueBonusGradeWeight>,
}Expand description
Строка таблицы уровней статуи
Fields
level: i64required_experience: i64slot_count: NonZeroU64sets_count: NonZeroU64grade_weights: NonEmptyVec<StatueBonusGradeWeight>Trait Implementations
Sourceimpl Clone for StatueLevelConfig
impl Clone for StatueLevelConfig
Sourcefn clone(&self) -> StatueLevelConfig
fn clone(&self) -> StatueLevelConfig
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StatueLevelConfig
impl Debug for StatueLevelConfig
Sourceimpl<'de> Deserialize<'de> for StatueLevelConfig
impl<'de> Deserialize<'de> for StatueLevelConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for StatueLevelConfig
impl JsonSchema for StatueLevelConfig
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for StatueLevelConfig
impl Serialize for StatueLevelConfig
Sourceimpl Tsify for StatueLevelConfig
impl Tsify for StatueLevelConfig
const DECL: &'static str = "/**\n * \u{421}\u{442}\u{440}\u{43e}\u{43a}\u{430} \u{442}\u{430}\u{431}\u{43b}\u{438}\u{446}\u{44b} \u{443}\u{440}\u{43e}\u{432}\u{43d}\u{435}\u{439} \u{441}\u{442}\u{430}\u{442}\u{443}\u{438}\n */\nexport interface StatueLevelConfig {\n level: number;\n required_experience: number;\n slot_count: NonZeroU64;\n sets_count: NonZeroU64;\n grade_weights: NonEmptyVec<StatueBonusGradeWeight>;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>