pub struct StatueRollCostConfig {
pub locked_count: u64,
pub cost: PositiveI64,
}Expand description
Стоимость ролла в зависимости от количества заблокированных слотов
Fields
locked_count: u64cost: PositiveI64Trait Implementations
Sourceimpl Clone for StatueRollCostConfig
impl Clone for StatueRollCostConfig
Sourcefn clone(&self) -> StatueRollCostConfig
fn clone(&self) -> StatueRollCostConfig
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StatueRollCostConfig
impl Debug for StatueRollCostConfig
Sourceimpl<'de> Deserialize<'de> for StatueRollCostConfig
impl<'de> Deserialize<'de> for StatueRollCostConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for StatueRollCostConfig
impl JsonSchema for StatueRollCostConfig
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for StatueRollCostConfig
impl Serialize for StatueRollCostConfig
Sourceimpl Tsify for StatueRollCostConfig
impl Tsify for StatueRollCostConfig
const DECL: &'static str = "/**\n * \u{421}\u{442}\u{43e}\u{438}\u{43c}\u{43e}\u{441}\u{442}\u{44c} \u{440}\u{43e}\u{43b}\u{43b}\u{430} \u{432} \u{437}\u{430}\u{432}\u{438}\u{441}\u{438}\u{43c}\u{43e}\u{441}\u{442}\u{438} \u{43e}\u{442} \u{43a}\u{43e}\u{43b}\u{438}\u{447}\u{435}\u{441}\u{442}\u{432}\u{430} \u{437}\u{430}\u{431}\u{43b}\u{43e}\u{43a}\u{438}\u{440}\u{43e}\u{432}\u{430}\u{43d}\u{43d}\u{44b}\u{445} \u{441}\u{43b}\u{43e}\u{442}\u{43e}\u{432}\n */\nexport interface StatueRollCostConfig {\n locked_count: number;\n cost: PositiveI64;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>