pub struct StatueSettings {
pub currency_id: CurrencyId,
pub roll_costs: NonEmptyVec<StatueRollCostConfig>,
}Expand description
Общие настройки статуи героя
Fields
currency_id: CurrencyIdroll_costs: NonEmptyVec<StatueRollCostConfig>Trait Implementations
Sourceimpl Clone for StatueSettings
impl Clone for StatueSettings
Sourcefn clone(&self) -> StatueSettings
fn clone(&self) -> StatueSettings
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StatueSettings
impl Debug for StatueSettings
Sourceimpl<'de> Deserialize<'de> for StatueSettings
impl<'de> Deserialize<'de> for StatueSettings
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for StatueSettings
impl JsonSchema for StatueSettings
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for StatueSettings
impl Serialize for StatueSettings
Sourceimpl Tsify for StatueSettings
impl Tsify for StatueSettings
const DECL: &'static str = "/**\n * \u{41e}\u{431}\u{449}\u{438}\u{435} \u{43d}\u{430}\u{441}\u{442}\u{440}\u{43e}\u{439}\u{43a}\u{438} \u{441}\u{442}\u{430}\u{442}\u{443}\u{438} \u{433}\u{435}\u{440}\u{43e}\u{44f}\n */\nexport interface StatueSettings {\n currency_id: CurrencyId;\n roll_costs: NonEmptyVec<StatueRollCostConfig>;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>